@@ -44,7 +44,7 @@ except ImportError:
 
 import filters
 from generic import *
-from utils import readNonWhitespace, readUntilWhitespace
+from utils import readNonWhitespace, readUntilWhitespace, ConvertFunctionsToVirtualList
 from sets import ImmutableSet
 
 class PdfFileWriter(object):
@@ -80,7 +80,7 @@ class PdfFileWriter(object):
         self._objects.append(obj)
         return IndirectObject(len(self._objects), 0, self)
 
-    def _getObject(self, ido):
+    def getObject(self, ido):
         assert ido.pdf == self
         return self._objects[ido.idnum - 1]
 
@@ -94,7 +94,7 @@ class PdfFileWriter(object):
         assert page["/Type"] == "/Page"
         page[NameObject("/Parent")] = self._pages
         page = self._addObject(page)
-        pages = self._getObject(self._pages)
+        pages = self.getObject(self._pages)
         pages["/Kids"].append(page)
         pages["/Count"] = NumberObject(pages["/Count"] + 1)
 
@@ -171,7 +171,7 @@ class PdfFileWriter(object):
                     return data
                 else:
                     self.stack.append(data.idnum)
-                    realdata = self._getObject(data)
+                    realdata = self.getObject(data)
                     self._sweepIndirectReferences(externMap, realdata)
                     self.stack.pop()
                     return data
@@ -226,6 +226,10 @@ class PdfFileReader(object):
         retval.update(obj)
         return retval
 
+    documentInfo = property(lambda self: self.getDocumentInfo(), None, None,
+            """See PdfFileReader.getDocumentInfo().  This property was added 
+            in pyPdf v1.7, and will exist for all future v1.x releases.""")
+
     def getNumPages(self):
         """
         Returns the number of pages in this PDF file.
@@ -236,6 +240,10 @@ class PdfFileReader(object):
             self._flatten()
         return len(self.flattenedPages)
 
+    numPages = property(lambda self: self.getNumPages(), None, None,
+            """See PdfFileReader.getNamePages().  This property was added in
+            v1.7, and will exist for all future v1.x releases.""")
+
     def getPage(self, pageNumber):
         """
         Retrieves a page by number from this PDF file.  Returns a PageObject
@@ -249,6 +257,10 @@ class PdfFileReader(object):
             self._flatten()
         return self.flattenedPages[pageNumber]
 
+    pages = property(lambda self: ConvertFunctionsToVirtualList(self.getNumPages, self.getPage),
+            None, None, """Returns a sequence of pages.  This property was
+            added in v1.7 and will exist for all future v1.x releases.""")
+
     def _flatten(self, pages = None, inherit = None):
         inheritablePageAttributes = (
             NameObject("/Resources"), NameObject("/MediaBox"),
@@ -635,6 +647,38 @@ class PageObject(DictionaryObject):
             content = ContentStream(content, self.pdf)
         self[NameObject("/Contents")] = content.flateEncode()
 
+    def extractText(self):
+        """
+        Locate all text drawing commands, in the order they are provided in
+        the content stream, and extract the text.  This works well for some
+        PDF files, but poorly for others, depending on the generator used.
+        This will be refined in the future.  Do not rely on the order of text
+        coming out of this function, as it will change if this function is 
+        made more sophisticated.
+
+        Stability: Added in v1.7, will exist for all v1.x releases thereafter.
+        May be overhauled to provide more ordered text in the future.
+        """
+        text = ""
+        content = self["/Contents"].getObject()
+        if not isinstance(content, ContentStream):
+            content = ContentStream(content, self.pdf)
+        for operands,operator in content.operations:
+            if operator == "Tj":
+                text += operands[0]
+            elif operator == "T*":
+                text += "\n"
+            elif operator == "'":
+                text += "\n"
+                text += operands[0]
+            elif operator == "\"":
+                text += "\n"
+                text += operands[2]
+            elif operator == "TJ":
+                for i in operands[0]:
+                    if isinstance(i, StringObject):
+                        text += i
+        return text
 
 addRectangleAccessor(PageObject, "mediaBox", "/MediaBox", (),
         """A rectangle, expressed in default user space units, defining the
